import * as T from "../generated/types.js";
import { EventType } from "../generated/types.js";
import { RawClient } from "../generated/client.js";
import { WebsocketTransport, BaseTransport } from "yerpc";
import { TinyEmitter } from "@deltachat/tiny-emitter";
type Events = {
    ALL: (accountId: number, event: EventType) => void;
} & {
    [Property in EventType["kind"]]: (accountId: number, event: Extract<EventType, {
        kind: Property;
    }>) => void;
};
type ContextEvents = {
    ALL: (event: EventType) => void;
} & {
    [Property in EventType["kind"]]: (event: Extract<EventType, {
        kind: Property;
    }>) => void;
};
export type DcEvent = EventType;
export type DcEventType<T extends EventType["kind"]> = Extract<EventType, {
    kind: T;
}>;
export declare class BaseDeltaChat<Transport extends BaseTransport<any>> extends TinyEmitter<Events> {
    transport: Transport;
    rpc: RawClient;
    account?: T.Account;
    private contextEmitters;
    private eventTask;
    constructor(transport: Transport, startEventLoop: boolean);
    eventLoop(): Promise<void>;
    listAccounts(): Promise<T.Account[]>;
    getContextEvents(account_id: number): TinyEmitter<ContextEvents>;
}
export type Opts = {
    url: string;
    startEventLoop: boolean;
};
export declare const DEFAULT_OPTS: Opts;
export declare class DeltaChat extends BaseDeltaChat<WebsocketTransport> {
    opts: Opts;
    close(): void;
    constructor(opts?: Opts | string);
}
export declare class StdioDeltaChat extends BaseDeltaChat<StdioTransport> {
    close(): void;
    constructor(input: any, output: any, startEventLoop: boolean);
}
export declare class StdioTransport extends BaseTransport {
    input: any;
    output: any;
    constructor(input: any, output: any);
    _send(message: any): void;
}
export {};
